Struct alloc::boxed::PinBox
[−]
[src]
pub struct PinBox<T: ?Sized> { /* fields omitted */ }A pinned, heap allocated reference.
Methods
impl<T> PinBox<T>[src]
pub fn new(data: T) -> PinBox<T>[src]
Allocate memory on the heap, move the data into it and pin it.
impl<T: ?Sized> PinBox<T>[src]
pub fn as_pin<'a>(&'a mut self) -> Pin<'a, T>[src]
Get a pinned reference to the data in this PinBox.
pub unsafe fn get_mut<'a>(this: &'a mut PinBox<T>) -> &'a mut T[src]
Get a mutable reference to the data inside this PinBox.
This function is unsafe. Users must guarantee that the data is never moved out of this reference.
ⓘImportant traits for Box<I>pub unsafe fn unpin(this: PinBox<T>) -> Box<T>[src]
ⓘImportant traits for Box<I>
Convert this PinBox into an unpinned Box.
This function is unsafe. Users must guarantee that the data is never moved out of the box.